package cn.wise.sc.cement.business.controller;

import cn.wise.sc.cement.business.entity.SysUser;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.enumation.FileExt;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.query.*;
import cn.wise.sc.cement.business.model.vo.EntrustVo;
import cn.wise.sc.cement.business.model.vo.SampleDistributionTeamVo;
import cn.wise.sc.cement.business.model.vo.SampleTeamGroupVo;
import cn.wise.sc.cement.business.model.vo.SampleVo;
import cn.wise.sc.cement.business.service.IEntrustService;
import cn.wise.sc.cement.business.util.WordUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author ztw
 * @since 2020-08-24
 */
@Api(tags = "委托管理")
@RestController
@RequestMapping("/business/entrust")
public class EntrustController {

	private static final Logger log = LoggerFactory.getLogger("EntrustController");

	@Autowired
	private IEntrustService entrustService;

	@ApiOperation(value = "委托分页列表")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "entrustCode", value = "委托单号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "startDate", value = "开始日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "endDate", value = "结束日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "status",
					value = "状态(0未评审，1已通过，2未通过，" +
							"3样品处理中，4样品处理完成，" +
							"5样品检测中，6样品检测完成，" +
							"7校核中，8校核完成,9修改待确认)", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientName", value = "委托单位id", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectCode", value = "项目编号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "isUrgent", value = "（1加急，0不加急）", paramType = "query", dataType = "Integer")
	})
	@GetMapping("/getPage")
	public BaseResponse getPage(PageQuery pageQuery, String entrustCode, String startDate, String endDate, Integer status,
	                            String clientName, String projectName, String projectCode, Integer isUrgent) {
		try {
			return entrustService.getPage(pageQuery, entrustCode, startDate, endDate, status, clientName, projectName, projectCode, isUrgent);
		} catch (Exception e) {
			log.debug("委托分页列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation("委托列表导出")
	@PostMapping("/export")
	public void export(String startDate, String endDate, Integer status,
	                   Integer clientId, String projectName, String projectCode,
	                   String fileName, HttpServletResponse response) {
		try {
			entrustService.export(startDate, endDate, status,
					clientId, projectName, projectCode,
					fileName, response);
		} catch (Exception e) {
			log.debug("委托列表导出{}", e);
		}
	}

	@ApiOperation(value = "置顶取消置顶 (createTime = updateTime显示置顶，否则显示取消置顶)")
	@PostMapping("/setTopping")
	public BaseResponse setTopping(Integer id) {
		try {
			return entrustService.setTopping(id);
		} catch (Exception e) {
			log.debug("置顶取消置顶{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "新增委托")
	@PostMapping("/create")
	public BaseResponse create(@RequestBody EntrustQuery query) {
		try {
			return entrustService.create(query);
		} catch (Exception e) {
			log.debug("新增委托{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "修改委托")
	@PostMapping("/update")
	public BaseResponse update(@RequestBody EntrustUpdateQuery query) {
		try {
			return entrustService.update(query);
		} catch (Exception e) {
			log.debug("修改委托{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "评审时删除委托样品")
	@PostMapping("/deleteSample/{sampleId}")
	public BaseResponse deleteSample(@PathVariable Integer sampleId) {
		try {
			return entrustService.deleteSample(sampleId);
		} catch (Exception e) {
			log.debug("评审时删除委托样品{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "委托详情")
	@GetMapping("/{id}")
	public BaseResponse getDtail(@PathVariable Integer id) {
		try {
			return entrustService.getDtail(id);
		} catch (Exception e) {
			log.debug("委托详情{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "获取样品表里最大的本所编号")
	@GetMapping("/getMaxCementCode")
	public BaseResponse getMaxCementCode() {
		try {
			return entrustService.getMaxCementCode();
		} catch (Exception e) {
			log.debug("获取样品表里最大的本所编号{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "委托评审+发送样品处理任务")
	@PostMapping("/approval")
	public BaseResponse approval(@RequestBody ApprovalQuery query) {
		try {
			return entrustService.approval(query);
		} catch (Exception e) {
			log.debug("委托评审+发送样品处理任务{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "委托人确认修改信息+发送样品处理任务")
	@PostMapping("/sureUpdate")
	public BaseResponse sureUpdate(@RequestBody sureUpdateQuery query) {
		try {
			return entrustService.sureUpdate(query);
		} catch (Exception e) {
			log.debug("委托人确认修改信息+发送样品处理任务{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}



	/*@ApiOperation(value = "发送样品处理任务")
	@PostMapping("/handle")
	public BaseResponse handle(@RequestBody HandleQuery query) {
		try {
			return entrustService.handle(query);
		} catch (Exception e) {
			log.debug("发送样品处理任务{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}*/

	@ApiOperation(value = "样品处理任务分页")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "entrustCode", value = "委托单号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "status",
					value = "状态(0未评审，1已通过，2未通过，" +
							"3样品处理中，4样品处理完成，" +
							"5样品检测中，6样品检测完成，" +
							"7校核中，8校核完成)", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientName", value = "委托单位id", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectCode", value = "项目编号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "isUrgent", value = "（1加急，0不加急）", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "handleStatus", value = "样品处理表状态（0未接受，1接受，2完成，3退回）", paramType = "query", dataType = "Integer")
	})
	@GetMapping("/getSampleHandlePage")
	public BaseResponse getSampleHandlePage(PageQuery pageQuery, String entrustCode, Integer status,
	                                        String clientName, String projectName, String projectCode,
	                                        Integer isUrgent,Integer handleStatus) {
		try {
			return entrustService.getSampleHandlePage(pageQuery, entrustCode, status, clientName, projectName,
					 projectCode, isUrgent, handleStatus);
		} catch (Exception e) {
			log.debug("样品处理任务分页{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "样品处理任务列表")
	@GetMapping("/getSampleHandleList")
	public BaseResponse getSampleHandleList(Integer id) {
		try {
			return entrustService.getSampleHandleList(id);
		} catch (Exception e) {
			log.debug("样品处理任务列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "样品处理详情")
	@GetMapping("/getHandleDtail/{id}")
	public BaseResponse getHandleDtail(@PathVariable Integer id) {
		try {
			return entrustService.getHandleDtail(id);
		} catch (Exception e) {
			log.debug("样品处理详情{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "完成样品处理任务")
	@PostMapping("/finishHandle")
	public BaseResponse finishHandle(Integer id) {
		try {
			return entrustService.finishHandle(id);
		} catch (Exception e) {
			log.debug("完成样品处理任务{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "样品处理任务退回")
	@PostMapping("/returnHandle")
	public BaseResponse returnHandle(@RequestBody ReturnQuery query) {
		try {
			return entrustService.returnHandle(query);
		} catch (Exception e) {
			log.debug("样品处理任务退回{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "样品处理退回任务分页（评审人员查看）")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "entrustCode", value = "委托单号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "userId", value = "接受人id", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientName", value = "委托单位id", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectCode", value = "项目编号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "isUrgent", value = "（1加急，0不加急）", paramType = "query", dataType = "Integer")
	})
	@GetMapping("/getSampleReturnHandlePage")
	public BaseResponse getSampleReturnHandlePage(PageQuery pageQuery, String entrustCode, Integer userId,
	                                        String clientName, String projectName, String projectCode, Integer isUrgent) {
		try {
			return entrustService.getSampleReturnHandlePage(pageQuery, entrustCode, userId, clientName, projectName, projectCode, isUrgent);
		} catch (Exception e) {
			log.debug("样品处理退回任务分页（评审人员查看）{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "重新派发样品处理任务（评审人员操作）")
	@PostMapping("/handleAgain")
	public BaseResponse handleAgain(@RequestBody HandleAgainQuery query) {
		try {
			return entrustService.handleAgain(query);
		} catch (Exception e) {
			log.debug("重新派发样品处理任务（评审人员操作）{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	//*******************样品检测*****************************************



	@ApiOperation(value = "派发样品检测-委托详情")
	@GetMapping("/getPFDtail/{id}")
	public BaseResponse getPFDtail(@PathVariable Integer id) {
		try {
			return entrustService.getDtail(id);
		} catch (Exception e) {
			log.debug("委托详情{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "派发检测项目任务")
	@PostMapping("/distribution")
	public BaseResponse distribution(@RequestBody DistributionQuery query) {
		try {
			return entrustService.distribution(query);
		} catch (Exception e) {
			log.debug("派发检测项目任务{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "派发任务分页列表")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "entrustCode", value = "委托单号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "status",
					value = "状态(0未评审，1已通过，2未通过，" +
							"3样品处理中，4样品处理完成，" +
							"5样品检测中，6样品检测完成，" +
							"7校核中，8校核完成)", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientName", value = "委托单位id", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectCode", value = "项目编号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "isUrgent", value = "（1加急，0不加急）", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "distributionStatus", value = "样品检测表状态（0未接受，1接受，2待校核，" +
					"3退回，4校核通过，5校核退回）", paramType = "query", dataType = "Integer")
	})
	@GetMapping("/getSampleDistributionPage")
	public BaseResponse getSampleDistributionPage(PageQuery pageQuery, String entrustCode, Integer status,
	                                              String clientName, String projectName, String projectCode, Integer isUrgent,
	                                              Integer distributionStatus ) {
		try {
			return entrustService.getSampleDistributionPage(pageQuery, entrustCode, status,
					clientName, projectName, projectCode, isUrgent, distributionStatus);
		} catch (Exception e) {
			log.debug("派发任务分页列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "检测通知单详情（派发的+校核退回）")
	@GetMapping("/getSampleDistributionList/{id}")
	public BaseResponse getSampleDistributionList(@PathVariable Integer id) {
		try {
			return entrustService.getSampleDistributionList(id);
		} catch (Exception e) {
			log.debug("检测通知单详情（派发的和校核退回）{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "详情-基本信息")
	@GetMapping("/getBaseDtail/{id}")
	public BaseResponse getBaseDtail(@PathVariable Integer id) {
		try {
			return entrustService.getBaseDtail(id);
		} catch (Exception e) {
			log.debug("详情-基本信息{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "详情-委托客户查看基本信息")
	@GetMapping("/getBaseDtailClient/{id}")
	public BaseResponse getBaseDtailClient(@PathVariable Integer id) {
		try {
			return entrustService.getBaseDtailClient(id);
		} catch (Exception e) {
			log.debug("详情-委托客户查看基本信息{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "详情-样品处理信息")
	@GetMapping("/getSampleHandleDtail/{id}")
	public BaseResponse getSampleHandleDtail(@PathVariable Integer id) {
		try {
			return entrustService.getSampleHandleDtail(id);
		} catch (Exception e) {
			log.debug("详情-样品处理信息{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "详情-检测任务信息")
	@GetMapping("/getSampleCheckDtail/{id}")
	public BaseResponse getSampleCheckDtail(@PathVariable Integer id) {
		try {
			return entrustService.getSampleCheckDtail(id);
		} catch (Exception e) {
			log.debug("详情-检测任务信息{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "接受检测项目任务")
	@PostMapping("/acceptDistribution")
	public BaseResponse acceptDistribution(@RequestBody Integer[] ids) {
		try {
			return entrustService.acceptDistribution(ids);
		} catch (Exception e) {
			log.debug("接受检测项目任务{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "完成检测项目任务（按组完成）+重新检测")
	@PostMapping("/finishDistribution")
	public BaseResponse finishDistribution(@RequestBody FinishCheckGroupQuery query) {
		try {
			return entrustService.finishDistribution(query);
		} catch (Exception e) {
			log.debug("完成检测项目任务{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "样品检测退回")
	@PostMapping("/returnDistribution")
	public BaseResponse returnDistribution(@RequestBody ReturnDistributionQuery query) {
		try {
			return entrustService.returnDistribution(query);
		} catch (Exception e) {
			log.debug("样品检测退回{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "样品检测退回任务分页")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "entrustCode", value = "委托单号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "userId", value = "接受人id", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientName", value = "委托单位id", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectCode", value = "项目编号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "isUrgent", value = "（1加急，0不加急）", paramType = "query", dataType = "Integer")
	})
	@GetMapping("/getSampleReturnDistributioPage")
	public BaseResponse getSampleReturnDistributioPage(PageQuery pageQuery, String entrustCode, Integer userId,
	                                              String clientName, String projectName, String projectCode, Integer isUrgent) {
		try {
			return entrustService.getSampleReturnDistributioPage(pageQuery, entrustCode, userId, clientName, projectName, projectCode, isUrgent);
		} catch (Exception e) {
			log.debug("样品检测退回任务分页{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "重新派发样品检测任务")
	@PostMapping("/distributioAgain")
	public BaseResponse distributioAgain(@RequestBody HandleAgainQuery query) {
		try {
			return entrustService.distributioAgain(query);
		} catch (Exception e) {
			log.debug("重新派发样品检测任务{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	//*******************样品校核 ****************************************

	@ApiOperation(value = "数据校核分页")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "startDate", value = "开始日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "endDate", value = "结束日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "status",
					value = "状态(0未评审，1已通过，2未通过，" +
							"3样品处理中，4样品处理完成，" +
							"5样品检测中，6样品检测完成，" +
							"7校核中，8校核完成)", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientId", value = "委托单位id", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectCode", value = "项目编号", paramType = "query", dataType = "String")
	})
	@GetMapping("/getCheckPage")
	public BaseResponse getCheckPage(PageQuery pageQuery, String startDate, String endDate, Integer status,
	                                 Integer clientId, String projectName, String projectCode) {
		try {
			return entrustService.getCheckPage(pageQuery, startDate, endDate, status, clientId, projectName, projectCode);
		} catch (Exception e) {
			log.debug("数据校核分页{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "数据校核详情列表")
	@GetMapping("/getCheckList/{id}")
	public BaseResponse getCheckList(@PathVariable Integer id) {
		try {
			return entrustService.getCheckList(id);
		} catch (Exception e) {
			log.debug("数据校核详情列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "校核计算 立马返回数据")
	@PostMapping("/checkCountFast")
	public BaseResponse checkCountFast(@RequestBody CheckCountFastQuery query) {
		try {
			return entrustService.checkCountFast(query);
		} catch (Exception e) {
			log.debug("校核计算 立马返回数据{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "数据校核结果查看")
	@GetMapping("/getCheckResult")
	public BaseResponse getCheckResult(Integer entrustId, Integer userId) {
		try {
			return entrustService.getCheckResult(entrustId, userId);
		} catch (Exception e) {
			log.debug("数据校核结果查看{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "校核计算")
	@PostMapping("/checkCount")
	public BaseResponse checkCount(@RequestBody CheckCountNewQuery query) {
		try {
			return entrustService.checkCountNew(query);
		} catch (Exception e) {
			log.debug("校核计算{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "数据校核退回任务分页（处理人+检测人员查看）")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "entrustCode", value = "委托单号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "status",
					value = "状态(0未评审，1已通过，2未通过，" +
							"3样品处理中，4样品处理完成，" +
							"5样品检测中，6样品检测完成，" +
							"7校核中，8校核完成)", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientName", value = "委托单位id", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "projectCode", value = "项目编号", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "isUrgent", value = "（1加急，0不加急）", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "distributionStatus", value = "样品检测表状态（0未接受，1接受，2待校核，" +
					"3退回，4校核通过，5校核退回）", paramType = "query", dataType = "Integer")
	})
	@GetMapping("/getSampleReturnCheckPage")
	public BaseResponse getSampleReturnCheckPage(PageQuery pageQuery, String entrustCode, Integer status,
	                                              String clientName, String projectName, String projectCode, Integer isUrgent,
	                                              Integer distributionStatus ) {
		try {
			return entrustService.getSampleReturnCheckPage(pageQuery, entrustCode, status,
					clientName, projectName, projectCode, isUrgent, distributionStatus);
		} catch (Exception e) {
			log.debug("数据校核退回任务分页（处理人+检测人员查看）{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	//*********************附件功能**************************************************
	@ApiOperation(value = "样品处理附件列表")
	@GetMapping("/getSampleHandleEnclosureList")
	public BaseResponse getSampleHandleEnclosureList(Integer sampleHandleId) {
		try {
			return entrustService.getSampleHandleEnclosureList(sampleHandleId);
		} catch (Exception e) {
			log.debug("样品处理附件列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "样品处理上传附件")
	@PostMapping("/uploadEnclosureCL")
	public BaseResponse uploadEnclosureCL(SampleHandleEnclosureQuery query) {
		try {
			return entrustService.uploadEnclosureCL(query);
		} catch (Exception e) {
			log.debug("样品处理上传附件{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "样品检测/校核附件列表")
	@GetMapping("/getSampleDistributionEnclosureList")
	public BaseResponse getSampleDistributionEnclosureList(Integer sampleDistributionId) {
		try {
			return entrustService.getSampleDistributionEnclosureList(sampleDistributionId);
		} catch (Exception e) {
			log.debug("样品检测/校核附件列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "样品检测/校核上传附件")
	@PostMapping("/uploadEnclosurePF")
	public BaseResponse uploadEnclosurePF(SampleHandleEnclosureQuery query) {
		try {
			return entrustService.uploadEnclosurePF(query);
		} catch (Exception e) {
			log.debug("样品检测/校核上传附件{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "删除附件")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "id", value = "样品表id/检测表id", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "type",value = "状态 0处理项，1检测项", paramType = "query", dataType = "Integer")
	})
	@PostMapping("/deleteEnclosure")
	public BaseResponse deleteEnclosure(Integer id,Integer type) {
		try {
			return entrustService.deleteEnclosure(id, type);
		} catch (Exception e) {
			log.debug("删除附件{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "设置附件是否公开（校核）")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "isPublic", value = "是否公开 0不公开 1公开", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "id", value = "样品表id/检测表id", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "type",value = "状态 0处理项，1检测项", paramType = "query", dataType = "Integer")
	})
	@PostMapping("/makePublicEnclosure")
	public BaseResponse makePublicEnclosure(Integer isPublic, Integer id,Integer type) {
		try {
			return entrustService.makePublicEnclosure(isPublic, id, type);
		} catch (Exception e) {
			log.debug("设置附件是否公开{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}



	//*********************导出**************************************************

	@PostMapping("/export/{entrustId}")
	@ApiOperation("导出委托单")
	public void getReportDetail(@PathVariable("entrustId") Integer entrustId,
	                            HttpServletResponse response) {
		EntrustVo entrustVo = entrustService.getBaseDtail(entrustId).getData();
		if (entrustVo == null) {
			return;
		}
		Map<String, Object> beanParams = new HashMap<>(7);
		beanParams.put("clientName", entrustVo.getClientName()==null?"":entrustVo.getClientName());
		beanParams.put("entrustCode", entrustVo.getEntrustCode()==null?"":entrustVo.getEntrustCode());
		beanParams.put("userName", entrustVo.getUserName()==null?"":entrustVo.getUserName());
		beanParams.put("userPhone", entrustVo.getUserPhone()==null?"":entrustVo.getUserPhone());
		beanParams.put("userFax", entrustVo.getUserFax()==null?"":entrustVo.getUserFax());
		beanParams.put("projectName", entrustVo.getProjectName()==null?"":entrustVo.getProjectName());
		beanParams.put("sampleNum", entrustVo.getSampleNum()==null?"":entrustVo.getSampleNum());

		//获取委托单样品列表(不包含平行样)
		List<SampleVo> sampleList = new ArrayList<>(entrustVo.getSampleList().size());
		entrustVo.getSampleList()
				.stream()
				.filter(arg -> arg.getCementCode().equals(arg.getParallelCode()) )
				.forEach(arg -> {
					List<SampleTeamGroupVo> teamVoList = arg.getSampleTeamGroupVoList();
					teamVoList.forEach(args ->{
						List<SampleDistributionTeamVo> teamVoList2 = args.getSampleDistributionTeamVoList();
						arg.setTeamName(getTeamName(teamVoList2));
					});
					sampleList.add(arg);
				});
		beanParams.put("list", sampleList);

		WordUtil.writeWordReportSXB(entrustVo.getEntrustCode() +"-"+ entrustVo.getProjectName() + "-委托单", "entrust2.ftl",
				beanParams, response, FileExt.DOC);

	}

	private String getTeamName(List<SampleDistributionTeamVo> teamVos) {
		if (teamVos.size() == 0) {
			return "";
		}

		StringBuffer rts = new StringBuffer();

		teamVos.forEach(arg -> {
			rts.append(arg.getTeamName()).append("、");
		});
		return rts.substring(0, rts.toString().length() - 1);
	}

}

